==> 1.0.0.zip: tubelab-app-android/app/src/main/java/app/fedilab/fedilabtube/asynctasks/RetrieveAccountsAsyncTask.java <==
package app.fedilab.fedilabtube.asynctasks;
/* Copyright 2020 Thomas Schneider
 *
 * This file is a part of TubeLab
 *
 * This program is free software; you can redistribute it and/or modify it under the terms of the
 * GNU General Public License as published by the Free Software Foundation; either version 3 of the
 * License, or (at your option) any later version.
 *
 * TubeLab is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even
 * the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General
 * Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along with TubeLab; if not,
 * see <http://www.gnu.org/licenses>. */

import android.content.Context;
import android.os.AsyncTask;

import java.lang.ref.WeakReference;

import app.fedilab.fedilabtube.client.APIResponse;
import app.fedilab.fedilabtube.client.PeertubeAPI;
import app.fedilab.fedilabtube.interfaces.OnRetrieveAccountsInterface;


public class RetrieveAccountsAsyncTask extends AsyncTask<Void, Void, Void> {

    private APIResponse apiResponse;
    private OnRetrieveAccountsInterface listener;
    private WeakReference<Context> contextReference;
    private String name;

    public RetrieveAccountsAsyncTask(Context context, String name, OnRetrieveAccountsInterface onRetrieveAccountsInterface) {
        this.contextReference = new WeakReference<>(context);
        this.name = name;
        this.listener = onRetrieveAccountsInterface;
    }


    @Override
    protected Void doInBackground(Void... params) {
        PeertubeAPI peertubeAPI = new PeertubeAPI(this.contextReference.get());
        apiResponse = peertubeAPI.getPeertubeChannel(name);
        return null;
    }

    @Override
    protected void onPostExecute(Void result) {
        listener.onRetrieveAccounts(apiResponse);
    }


}

==> 1.0.3.zip: tubelab-app-android/app/src/main/java/app/fedilab/fedilabtube/asynctasks/RetrieveAccountsAsyncTask.java <==
package app.fedilab.fedilabtube.asynctasks;
/* Copyright 2020 Thomas Schneider
 *
 * This file is a part of TubeLab
 *
 * This program is free software; you can redistribute it and/or modify it under the terms of the
 * GNU General Public License as published by the Free Software Foundation; either version 3 of the
 * License, or (at your option) any later version.
 *
 * TubeLab is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even
 * the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General
 * Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along with TubeLab; if not,
 * see <http://www.gnu.org/licenses>. */

import android.content.Context;
import android.os.AsyncTask;

import java.lang.ref.WeakReference;

import app.fedilab.fedilabtube.client.APIResponse;
import app.fedilab.fedilabtube.client.PeertubeAPI;
import app.fedilab.fedilabtube.interfaces.OnRetrieveAccountsInterface;


public class RetrieveAccountsAsyncTask extends AsyncTask<Void, Void, APIResponse> {

    private OnRetrieveAccountsInterface listener;
    private WeakReference<Context> contextReference;
    private String max_id;
    private accountFetch type;

    public RetrieveAccountsAsyncTask(Context context, String max_id, accountFetch type, OnRetrieveAccountsInterface onRetrieveAccountsInterface) {
        this.contextReference = new WeakReference<>(context);
        this.max_id = max_id;
        this.listener = onRetrieveAccountsInterface;
        this.type = type;
    }

    @Override
    protected APIResponse doInBackground(Void... params) {
        PeertubeAPI peertubeAPI = new PeertubeAPI(this.contextReference.get());
        if (type == accountFetch.SUBSCRIPTION) {
            return peertubeAPI.getSubscriptionUsers(max_id);
        } else if (type == accountFetch.MUTED) {
            return peertubeAPI.getMuted(max_id);
        } else if (type == accountFetch.CHANNEL) {
            return peertubeAPI.getPeertubeChannel(max_id);
        } else {
            return null;
        }
    }

    @Override
    protected void onPostExecute(APIResponse apiResponse) {
        listener.onRetrieveAccounts(apiResponse);
    }

    public enum accountFetch {
        SUBSCRIPTION,
        CHANNEL,
        MUTED
    }

}
